---
home: true
title: Home
heroImage: /baygon.svg
actions:
  - text: Get Started
    link: /guide
    type: primary
  - text: Syntax
    link: /guide/syntax.md
    type: secondary
footer: MIT Licensed | Copyright © HEIG-VD 2021-present
---
